# Installation | Установка

## Windows
```
pip install aaiopay
```
## Linux
```
pip3 install aaiopay
```


# Information | Информация
ENG: The current version of AaioPay is 0.2.2
RU: Актуальная версия AaioPay 0.2.2

# Methods | Фyнкции
## ENG
```
Asynchronous module for working with the Aaio API

What can?
- Getting a balance
- Creating a payment form
- Getting up-to-date transactions
 ```

## RU
```
Асинхронный модуль для работы с API Aaio

Что может?
- Получение баланса
- Создание формы оплаты
- Получение актуальных транзакций
```